# nada-dsl

nada-dsl is a Python DSL for building MPC programs on the Nillion Network.

See the official Nillion documentation site for more about the [Nada Language][nada-language] and
[Nada By Example][examples].

[examples]: https://docs.nillion.com/nada-by-example
[nada-language]: https://docs.nillion.com/nada-lang
